==> doctorlink-design-system-1.1.5.tgz: package/es/Components/TextField/TextField.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { Label, Toggle, Link, ErrorText, Caption, TextFieldComponent, TextInput, TextInputContainer } from './TextFieldComponents';

class TextField extends React.Component {
  constructor(...args) {
    var _temp;

    return _temp = super(...args), this.state = {
      inputFocused: false
    }, _temp;
  }

  render() {
    const {
      label,
      caption,
      onChange,
      toggle,
      error,
      link,
      onToggle,
      disabled,
      theme,
      type,
      value
    } = this.props;
    const { inputFocused } = this.state;
    return React.createElement(
      TextFieldComponent,
      null,
      label && React.createElement(
        Label,
        null,
        label
      ),
      caption && React.createElement(
        Caption,
        null,
        caption
      ),
      React.createElement(
        TextInputContainer,
        {
          isFocused: inputFocused,
          theme: theme,
          disabled: disabled,
          error: error
        },
        React.createElement(TextInput, {
          value: value,
          type: type,
          onChange: onChange,
          disabled: disabled,
          onFocus: () => this.setState({ inputFocused: true }),
          onBlur: () => this.setState({ inputFocused: false })
        }),
        toggle && React.createElement(
          Toggle,
          { onClick: onToggle },
          toggle
        )
      ),
      error && React.createElement(
        ErrorText,
        null,
        error
      ),
      link && React.createElement(
        Link,
        { href: link.href, wholeLine: true, variation: 'small' },
        link.label
      )
    );
  }
}

TextField.propTypes = process.env.NODE_ENV !== "production" ? {
  caption: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.string,
  label: PropTypes.string,
  link: PropTypes.shape({
    label: PropTypes.string,
    href: PropTypes.string
  }),
  onChange: PropTypes.func,
  onToggle: PropTypes.func,
  value: PropTypes.string,
  theme: PropTypes.object,
  toggle: PropTypes.string,
  type: PropTypes.string
} : {};

TextField.defaultProps = {
  label: null,
  error: null,
  link: null,
  caption: null,
  type: 'text'
};

export default TextField;

==> doctorlink-design-system-1.1.6.tgz: package/es/Components/TextField/TextField.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { Label, Toggle, Link, ErrorText, Caption, TextFieldComponent, TextInput, TextInputContainer } from './TextFieldComponents';

class TextField extends React.Component {
  constructor(...args) {
    var _temp;

    return _temp = super(...args), this.state = {
      inputFocused: false
    }, _temp;
  }

  render() {
    const {
      label,
      caption,
      onChange,
      toggle,
      error,
      link,
      onToggle,
      disabled,
      theme,
      type,
      value
    } = this.props;
    const { inputFocused } = this.state;
    return React.createElement(
      TextFieldComponent,
      null,
      label && React.createElement(
        Label,
        null,
        label
      ),
      caption && React.createElement(
        Caption,
        null,
        caption
      ),
      React.createElement(
        TextInputContainer,
        {
          isFocused: inputFocused,
          theme: theme,
          disabled: disabled,
          error: error
        },
        React.createElement(TextInput, {
          value: value,
          type: type,
          onChange: onChange,
          disabled: disabled,
          onFocus: () => this.setState({ inputFocused: true }),
          onBlur: () => this.setState({ inputFocused: false })
        }),
        toggle && React.createElement(
          Toggle,
          { onClick: onToggle },
          toggle
        )
      ),
      error && React.createElement(
        ErrorText,
        null,
        error
      ),
      link && React.createElement(
        Link,
        { href: link.href, wholeLine: true, variation: 'small' },
        link.label
      )
    );
  }
}

TextField.propTypes = process.env.NODE_ENV !== "production" ? {
  caption: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.string,
  label: PropTypes.string,
  link: PropTypes.shape({
    label: PropTypes.string,
    href: PropTypes.string
  }),
  onChange: PropTypes.func,
  onToggle: PropTypes.func,
  theme: PropTypes.object,
  toggle: PropTypes.string,
  type: PropTypes.string,
  value: PropTypes.string
} : {};

TextField.defaultProps = {
  label: null,
  error: null,
  link: null,
  caption: null,
  type: 'text'
};

export default TextField;
